@@ -64,12 +64,7 @@ void DragHelper::startDrag(QQuickItem *item, QMimeData *mimeData, const QIcon &i
         Q_ARG(QQuickItem*, item), Q_ARG(QMimeData*, mimeData), Q_ARG(QIcon, icon));
 }
 
-void DragHelper::startDrag(QQuickItem *item, QMimeData *mimeData, const QString &iconName)
-{
-    startDrag(item, mimeData, QIcon::fromTheme(iconName));
-}
-
-void DragHelper::doDrag(QQuickItem *item, QMimeData *mimeData, const QIcon &icon) const
+void DragHelper::doDrag(QQuickItem *item, QMimeData *mimeData, const QIcon &icon)
 {
     QDrag *drag = new QDrag(item);
     drag->setMimeData(mimeData);
